@@ -14,14 +14,16 @@ class LogLevel(Enum):
     return NotImplemented
 
   def __gt__(self, other):
-    if self.__class__ is other.__class__:
-      return self.value > other.value
-    return NotImplemented
+    return self.value > other.value
 
   def __ge__(self, other):
-    if self.__class__ is other.__class__:
-      return self.value >= other.value
-    return NotImplemented
+    return self.value >= other.value
+
+  def __lt__(self, other):
+    return self.value < other.value
+
+  def __le__(self, other):
+    return self.value <= other.value
 
 
 class OrderSide(Enum):
